@@ -34,12 +34,12 @@ class simplelrucache:
         raise KeyError
 
 
-    def __setitem__(self, key, obj):
+    def __setitem__(self, key, value):
 
         for i in range(len(self.cache)):
             x = self.cache[i]
             if x[0] == key:
-                x[1] = obj
+                x[1] = value
                 del self.cache[i]
                 self.cache.append(x)
                 return
@@ -47,7 +47,7 @@ class simplelrucache:
         if len(self.cache) == self.size:
             self.cache = self.cache[1:]
 
-        self.cache.append([key, obj])
+        self.cache.append([key, value])
 
 
     def __delitem__(self, key):
@@ -59,6 +59,12 @@ class simplelrucache:
 
         raise KeyError
 
+    def resize(self, x=None):
+        assert x > 0
+        self.size = x
+        if x < len(self.cache):
+            del self.cache[:len(self.cache) - x]
+
 
 def test(a, b, c, d, verify):
 
@@ -96,7 +102,7 @@ def testcache():
         q = []
         z = a.head
         for j in range(len(a.table)):
-            q.append([z.key, z.obj])
+            q.append([z.key, z.value])
             z = z.next
 
         assert q == b.cache[::-1]
@@ -112,7 +118,22 @@ def testcache():
 
     a = lrucache(128)
     b = simplelrucache(128)
+    verify(a, b)
+    test(a, b, a, b, verify)
 
+    a.size(71)
+    b.resize(71)
+    verify(a, b)
+    test(a, b, a, b, verify)
+
+    a.size(341)
+    b.resize(341)
+    verify(a, b)
+    test(a, b, a, b, verify)
+
+    a.size(127)
+    b.resize(127)
+    verify(a, b)
     test(a, b, a, b, verify)
 
 
@@ -122,13 +143,13 @@ def wraptest():
         assert p == x.store
         for key, value in x.cache.items():
             assert x.store[key] == value
-            
+
         tmp = list(x.items())
         tmp.sort()
-        
+
         tmp2 = list(p.items())
         tmp2.sort()
-        
+
         assert tmp == tmp2
 
     p = dict()
@@ -145,20 +166,20 @@ def wraptest2():
         for key, value in x.store.items():
             if key not in x.dirty:
                 assert p[key] == value
-                
+
         for key in x.dirty:
             assert x.cache.peek(key) == p[key]
-            
+
         for key, value in x.cache.items():
             if key not in x.dirty:
                 assert x.store[key] == p[key] == value
-                
+
         tmp = list(x.items())
         tmp.sort()
-        
+
         tmp2 = list(p.items())
         tmp2.sort()
-        
+
         assert tmp == tmp2
 
     p = dict()
@@ -176,10 +197,10 @@ def wraptest3():
         for key, value in x.store.items():
             if key not in x.dirty:
                 assert p[key] == value
-                
+
         for key in x.dirty:
             assert x.cache.peek(key) == p[key]
-            
+
         for key, value in x.cache.items():
             if key not in x.dirty:
                 assert x.store[key] == p[key] == value
